package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.BusPatient;
import org.apache.ibatis.annotations.Param;

/**
 * 患者Mapper接口
 * 
 * @author zsl
 * @date 2022-06-02
 */
public interface BusPatientMapper 
{
    /**
     * 查询患者
     * 
     * @param id 患者主键
     * @return 患者
     */
    public BusPatient selectBusPatientById(Long id);

    /**
     * 查询患者列表
     * 
     * @param busPatient 患者
     * @return 患者集合
     */
    public List<BusPatient> selectBusPatientList(BusPatient busPatient);

    /**
     * 新增患者
     * 
     * @param busPatient 患者
     * @return 结果
     */
    public int insertBusPatient(BusPatient busPatient);

    /**
     * 修改患者
     * 
     * @param busPatient 患者
     * @return 结果
     */
    public int updateBusPatient(BusPatient busPatient);

    /**
     * 删除患者
     * 
     * @param id 患者主键
     * @return 结果
     */
    public int deleteBusPatientById(Long id);

    /**
     * 批量删除患者
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusPatientByIds(Long[] ids);

    /**
     * 修改患者状态
     *
     * @param ids 需要修改的数据主键集合
     * @param status  需要修改的状态
     * @return 结果
     */
    public int updateStatusByIds(@Param("ids") Long[] ids , @Param("status") Integer status);
}
